@@ -12,11 +12,6 @@
 #'
 #' Mouse MSigDB includes gene sets curated from mouse-centric datasets and specified in native mouse gene identifiers, eliminating the need for ortholog mapping.
 #'
-#' To access the full dataset, please install the msigdbdf package (not available on CRAN):
-#' ```
-#' install.packages("msigdbdf", repos = "https://igordot.r-universe.dev")
-#' ```
-#'
 #' @param species Species name for output genes, such as `"Homo sapiens"` or `"Mus musculus"`. Use `msigdbr_species()` for available options.
 #' @param db_species Species abbreviation for the human or mouse databases (`"HS"` or `"MM"`).
 #' @param collection Collection abbreviation, such as `"H"` or `"C1"`. Use `msigdbr_collections()` for the available options.
@@ -24,7 +19,7 @@
 #' @param category `r lifecycle::badge("deprecated")` use the `collection` argument
 #' @param subcategory `r lifecycle::badge("deprecated")` use the `subcollection` argument
 #'
-#' @return A data frame of gene sets with one gene per row.
+#' @return A tibble (a data frame with class [`tibble::tbl_df`]) of gene sets with one gene per row.
 #'
 #' @references <https://www.gsea-msigdb.org/gsea/msigdb/index.jsp>
 #'
@@ -77,19 +72,9 @@ msigdbr <- function(species = "Homo sapiens", db_species = "HS", collection = NU
     subcollection <- subcategory
   }
 
-  # Use an internal dataset for minimal functionality without msigdbdf
-  if (db_species == "HS") {
-    msigdbr_check_data(require_data = FALSE)
-  } else {
-    msigdbr_check_data(require_data = TRUE)
-  }
-
-  # Get the gene sets table from msigdbdf or use an internal test dataset
-  if (rlang::is_installed("msigdbdf")) {
-    mdb <- msigdbdf::msigdbdf(target_species = db_species)
-  } else {
-    mdb <- testdb
-  }
+  # Get the gene sets table
+  mdb <- load_msigdb_df(target_species = db_species)
+  mdb <- tibble::as_tibble(mdb)
 
   # Filter by collection
   if (is.character(collection)) {
@@ -140,6 +125,7 @@ msigdbr <- function(species = "Homo sapiens", db_species = "HS", collection = NU
       num_ortholog_sources = "support_n",
       !tidyselect::any_of(c("human_symbol", "human_entrez"))
     )
+    species_genes$ncbi_gene <- as.character(species_genes$ncbi_gene)
   }
 
   # Remove duplicate entries
